#[non_exhaustive]pub enum Error {
Http(HttpError),
Timeout(Duration),
Api {
status: u16,
reason: String,
},
RateLimited {
retry_after: Option<Duration>,
},
JsonDecode(Error),
InvalidResponse {
reason: String,
},
InvalidParam {
field: &'static str,
reason: String,
},
MutuallyExclusive {
first: &'static str,
second: &'static str,
},
TimeParse {
value: String,
reason: String,
},
}Expand description
Errors returned by the Open-Meteo client.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Http(HttpError)
The HTTP request failed before a response could be decoded.
Timeout(Duration)
The HTTP request timed out.
Api
The Open-Meteo API returned an error response.
RateLimited
The API returned a rate-limit response.
Fields
JsonDecode(Error)
JSON decoding failed.
InvalidResponse
Response content had an unexpected shape.
InvalidParam
A request parameter was invalid before the request was sent.
MutuallyExclusive
Two mutually exclusive request parameters were both set.
TimeParse
Timestamp parsing failed.