Client

Struct Client 

pub struct Client { /* private fields */ }
Async Open-Meteo API client.

Implementations

Source

impl Client

pub fn new() -> Self

Constructs a client using the public free-tier Open-Meteo forecast API.

Panics only if the crate’s built-in default client configuration is invalid or the internal HTTP client cannot be constructed.

pub fn builder() -> ClientBuilder

Starts a custom client builder.

pub fn forecast(&self, latitude: f64, longitude: f64) -> ForecastBuilder<'_>

Starts a general forecast request for one coordinate.

pub fn forecast_batch<I>(&self, locations: I) -> ForecastBatchBuilder<'_>
where I: IntoIterator<Item = (f64, f64)>,

Starts a general forecast request for multiple coordinates.

pub fn forecast_many<I>(&self, locations: I) -> ForecastBatchBuilder<'_>
where I: IntoIterator<Item = (f64, f64)>,

pub fn archive( &self, latitude: f64, longitude: f64, start_date: Date, end_date: Date, ) -> ArchiveBuilder<'_>

Starts an archive request for one coordinate and an inclusive date range.

pub fn historical_forecast( &self, latitude: f64, longitude: f64, start_date: Date, end_date: Date, ) -> HistoricalForecastBuilder<'_>

Starts a historical forecast request for one coordinate and an inclusive date range.

pub fn previous_runs( &self, latitude: f64, longitude: f64, ) -> PreviousRunsBuilder<'_>

Starts a previous model runs request for one coordinate.

pub fn ensemble(&self, latitude: f64, longitude: f64) -> EnsembleBuilder<'_>

Starts an ensemble forecast request for one coordinate.

pub fn seasonal(&self, latitude: f64, longitude: f64) -> SeasonalBuilder<'_>

Starts a seasonal forecast request for one coordinate.

pub fn climate( &self, latitude: f64, longitude: f64, start_date: Date, end_date: Date, ) -> ClimateBuilder<'_>

Starts a climate projection request for one coordinate and an inclusive date range.

pub fn satellite_radiation( &self, latitude: f64, longitude: f64, ) -> SatelliteRadiationBuilder<'_>

Starts a satellite-radiation request for one coordinate.

pub fn flood(&self, latitude: f64, longitude: f64) -> FloodBuilder<'_>

Starts a flood forecast request for one coordinate.

pub fn marine(&self, latitude: f64, longitude: f64) -> MarineBuilder<'_>

Starts a marine forecast request for one coordinate.

pub fn air_quality( &self, latitude: f64, longitude: f64, ) -> AirQualityBuilder<'_>

Starts an air-quality request for one coordinate.

pub fn geocode(&self, name: impl Into<String>) -> GeocodingBuilder<'_>

Starts a geocoding request by place name.

use openmeteo_rs::Client;

let client = Client::new();
let locations = client
    .geocode("Zurich")
    .count(1)
    .language("en")
    .send()
    .await?;

if let Some(location) = locations.first() {
    println!("{}, {}", location.latitude, location.longitude);
}
Source

impl Client

pub async fn elevation<I>(&self, points: I) -> Result<Vec<Option<f32>>>
where I: IntoIterator<Item = (f64, f64)>,

Looks up elevations for one or more coordinates.

Returned values are metres above sea level and preserve the input coordinate order. A value is None when Open-Meteo has no elevation coverage for that coordinate. Open-Meteo accepts at most 100 coordinate pairs per elevation request.

use openmeteo_rs::Client;

let client = Client::new();
let elevations = client
    .elevation([(52.52, 13.41), (47.3769, 8.5417)])
    .await?;

assert_eq!(elevations.len(), 2);