ClimateModel

Enum ClimateModel 

#[non_exhaustive]
pub enum ClimateModel { CmccCm2Vhr4, EcEarth3PHr, FgoalsF3H, HiramSitHr, MpiEsm12Xr, MriAgcm32S, Nicam168S, Other(Cow<'static, str>), }
Model selector for climate projection requests.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


CmccCm2Vhr4

CMCC CM2 VHR4 high-resolution climate model.



EcEarth3PHr

EC-Earth3P HR high-resolution climate model.



FgoalsF3H

FGOALS f3 H high-resolution climate model.



HiramSitHr

HiRAM SIT HR high-resolution climate model.



MpiEsm12Xr

MPI ESM1.2 XR high-resolution climate model.



MriAgcm32S

MRI AGCM3.2 S high-resolution climate model.



Nicam168S

NICAM16 8S high-resolution climate model.



Other(Cow<'static, str>)

Exact Open-Meteo climate model token not yet represented by this enum.

The token is passed through unchanged and is not validated by the crate.

Implementations

Source

impl ClimateModel

pub fn other(token: impl Into<Cow<'static, str>>) -> Self

Creates an exact Open-Meteo climate model token not yet represented by this enum.

The token is passed through unchanged and is not validated by the crate.