#[non_exhaustive]pub enum WeatherModel {
BestMatch,
GfsSeamless,
EcmwfIfs025,
IconSeamless,
MeteofranceSeamless,
Other(Cow<'static, str>),
}Expand description
Weather model selector for forecast requests.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
BestMatch
Open-Meteo’s automatic best-match model.
GfsSeamless
NOAA GFS seamless model.
EcmwfIfs025
ECMWF IFS 0.25 degree model.
IconSeamless
DWD ICON seamless model.
MeteofranceSeamless
MeteoFrance seamless model.
Other(Cow<'static, str>)
Exact Open-Meteo model token not yet represented by this enum.
This is an escape hatch for documented model names that have not been promoted to first-class variants yet. The token is not validated by the crate.
Implementations